@@ -35,6 +35,7 @@ from ...branch import Branch
 from ...controldir import ControlDir
 from ...commands import Command
 from ...errors import (
+    BzrError,
     BzrCommandError,
     FileExists,
     NotBranchError,
@@ -102,10 +103,15 @@ export_upstream_revision_opt = Option(
     type=str, argname="REVISION")
 
 
+class StrictBuildFailed(BzrCommandError):
+
+    _fmt = ("Build refused because there are unknown files in the tree. "
+            "To list all known files, run 'bzr unknowns'.")
+
+
 def _check_tree(tree, subpath, strict=False):
     if strict:
         for unknown in tree.unknowns():
-            from .errors import StrictBuildFailed
             raise StrictBuildFailed()
 
     if len(tree.conflicts()) > 0:
@@ -167,28 +173,31 @@ def _get_changelog_info(tree, subpath, last_version=None, package=None,
 
 def _get_upstream_branch_source(
         export_upstream, export_upstream_revision, config, version,
-        other_repository=None):
+        other_repository=None, guess_upstream_url=None):
     if export_upstream is None and config.upstream_branch:
         export_upstream = config.upstream_branch
     if export_upstream is None:
-        return None
+        if guess_upstream_url is None:
+            return None
+        export_upstream = guess_upstream_url
     from .upstream.branch import (
         LazyUpstreamBranchSource,
         )
     upstream_revision_map = {}
     if export_upstream_revision:
         upstream_revision_map[version] = export_upstream_revision
-    upstream_source = LazyUpstreamBranchSource(
+    return LazyUpstreamBranchSource(
         export_upstream, config=config,
         upstream_revision_map=upstream_revision_map,
         other_repository=other_repository)
-    return upstream_source
 
 
 def _get_upstream_sources(local_tree, subpath, packaging_branch,
                           build_type, config, upstream_version, top_level,
                           export_upstream=None,
-                          export_upstream_revision=None):
+                          export_upstream_revision=None,
+                          trust_package=True,
+                          guess_upstream_branch_url=False):
     from .upstream import (
         AptSource,
         SelfSplitSource,
@@ -201,18 +210,33 @@ def _get_upstream_sources(local_tree, subpath, packaging_branch,
     from .upstream.pristinetar import (
         get_pristine_tar_source,
         )
-    from .upstream.branch import (
-        LazyUpstreamBranchSource,
-        )
     yield get_pristine_tar_source(local_tree, packaging_branch)
     yield AptSource()
     try:
         yield UScanSource.from_tree(local_tree, subpath, top_level)
     except NoWatchFile:
         pass
+
+    if guess_upstream_branch_url:
+        try:
+            from upstream_ontologist.guess import (
+                guess_upstream_metadata,
+                )
+        except ModuleNotFoundError:
+            guess_upstream_url = None
+        else:
+            def guess_upstream_url():
+                guessed_upstream_metadata = guess_upstream_metadata(
+                    local_tree.abspath(subpath), trust_package=trust_package,
+                    net_access=True, consult_external_directory=False)
+                return guessed_upstream_metadata.get('Repository')
+    else:
+        guess_upstream_url = None
+
     upstream_branch_source = _get_upstream_branch_source(
         export_upstream, export_upstream_revision, config,
-        upstream_version, other_repository=packaging_branch.repository)
+        upstream_version, other_repository=packaging_branch.repository,
+        guess_upstream_url=guess_upstream_url)
     if upstream_branch_source:
         yield upstream_branch_source
 
@@ -226,7 +250,8 @@ def _get_distiller(
         tree, subpath, packaging_branch, changelog, build_type, config,
         contains_upstream_source=True, top_level=False,
         orig_dir=default_orig_dir, use_existing=False,
-        export_upstream=None, export_upstream_revision=None):
+        export_upstream=None, export_upstream_revision=None,
+        guess_upstream_branch_url=False):
     from .util import (
         guess_build_type,
         )
@@ -252,7 +277,8 @@ def _get_distiller(
         tree, subpath, packaging_branch, build_type=build_type,
         config=config, upstream_version=changelog.version.upstream_version,
         top_level=top_level, export_upstream=export_upstream,
-        export_upstream_revision=export_upstream_revision))
+        export_upstream_revision=export_upstream_revision,
+        guess_upstream_branch_url=guess_upstream_branch_url))
 
     upstream_provider = UpstreamProvider(
         changelog.package, changelog.version.upstream_version, orig_dir,
@@ -335,6 +361,10 @@ class cmd_builddeb(Command):
         'package-merge', help="Build using the "
         "appropriate -v and -sa options for merging in the changes from "
         "another source.")
+    guess_upstream_branch_url_opt = Option(
+        'guess-upstream-branch-url', help=(
+            'Guess upstream branch URL if unknown '
+            '(requires upstream-ontologist)'))
     takes_args = ['branch_or_build_options*']
     aliases = ['bd', 'debuild']
     takes_options = [
@@ -342,7 +372,7 @@ class cmd_builddeb(Command):
         builder_opt, merge_opt, build_dir_opt, orig_dir_opt, split_opt,
         export_upstream_opt, export_upstream_revision_opt, quick_opt,
         reuse_opt, native_opt, source_opt, 'revision', strict_opt,
-        package_merge_opt]
+        package_merge_opt, guess_upstream_branch_url_opt]
 
     def _get_tree_and_branch(self, location):
         if location is None:
@@ -450,15 +480,13 @@ class cmd_builddeb(Command):
             orig_dir=None, split=None,
             quick=False, reuse=False, native=None,
             source=False, revision=None, package_merge=None,
-            strict=False):
+            strict=False, guess_upstream_branch_url=False):
         from .builder import DebBuild
         from .config import UpstreamMetadataSyntaxError
-        from .errors import (
-            NoPreviousUpload,
-            )
         from .hooks import run_hook
         from .source_distiller import DebcargoError
         from .util import (
+            NoPreviousUpload,
             dget_changes,
             find_changelog,
             find_previous_upload,
@@ -517,7 +545,8 @@ class cmd_builddeb(Command):
                 contains_upstream_source=contains_upstream_source,
                 orig_dir=orig_dir, use_existing=use_existing,
                 top_level=top_level, export_upstream=export_upstream,
-                export_upstream_revision=export_upstream_revision)
+                export_upstream_revision=export_upstream_revision,
+                guess_upstream_branch_url=guess_upstream_branch_url)
 
             build_source_dir = os.path.join(
                 build_dir,
@@ -719,10 +748,8 @@ class cmd_merge_upstream(Command):
     def _add_changelog_entry(self, tree, subpath, package, version,
                              distribution_name, changelog):
         from .merge_upstream import (
-            changelog_add_new_version)
-        from .errors import (
             DchError,
-            )
+            changelog_add_new_version)
         try:
             changelog_add_new_version(
                 tree, subpath, version, distribution_name, changelog, package)
@@ -924,8 +951,7 @@ class cmd_merge_upstream(Command):
                 orig_dir = config.orig_dir or default_orig_dir
                 try:
                     tarball_filenames = get_tarballs(
-                        orig_dir, tree, package, version, upstream_branch,
-                        upstream_revisions, locations)
+                        orig_dir, tree, package, version, locations)
                 except FileExists as e:
                     raise BzrCommandError(
                         "The target file %s already exists, and is either "
@@ -934,7 +960,7 @@ class cmd_merge_upstream(Command):
                         "file, or use it as the argument to import."
                         % e.path)
                 try:
-                    conflicts = do_merge(
+                    conflicts, imported_revids = do_merge(
                         tree, subpath, tarball_filenames, package, version,
                         current_version, upstream_branch, upstream_revisions,
                         merge_type, force=force,
@@ -1193,7 +1219,8 @@ class cmd_import_upstream(Command):
                 'bzr import-upstream --revision takes exactly'
                 ' one revision specifier.'))
         tarballs = [(location, None, md5sum_filename(location))]
-        for (component, tag_name, revid) in db.import_upstream_tarballs(
+        for (component, tag_name, revid,
+             pristine_tar_imported) in db.import_upstream_tarballs(
                 tarballs, None, version, parents, upstream_branch=upstream,
                 upstream_revisions={None: upstream_revid},
                 force_pristine_tar=force_pristine_tar):
@@ -1405,54 +1432,6 @@ class cmd_mark_uploaded(Command):
             self.outf.write(gettext("Tag '%s' created.\n") % tag_name)
 
 
-class cmd_dh_make(Command):
-    """Helps you create a new package.
-
-    This code wraps dh_make to do the Bazaar setup for you, ensuring that
-    your branches have all the necessary information and are correctly
-    linked to the upstream branches where necessary.
-
-    The basic use case is satisfied by
-
-        bzr dh-make project 0.1 http://project.org/project-0.1.tar.gz
-
-    which will import the tarball with the correct tags etc. and then
-    run dh_make for you in order to start the packaging.
-
-    If there upstream is available in bzr then run the command from the
-    root of a branch of that corresponding to the 0.1 release.
-
-    If there is no upstream available in bzr then run the command from
-    outside a branch and it will create a branch for you in a directory
-    named the same as the package name you specify as the second argument.
-
-    If you do not wish to use dh_make, but just take advantage of the
-    Bazaar specific parts then use the --bzr-only option.
-    """
-
-    aliases = ['dh_make']
-
-    takes_args = ['package_name', 'version', 'tarball']
-
-    bzr_only_opt = Option('bzr-only', help="Don't run dh_make.")
-    use_pristine_tar_opt = Option(
-        'use-pristine-tar', help='Whether to use pristine-tar.')
-
-    takes_options = [bzr_only_opt]
-
-    def run(self, package_name, version, tarball, bzr_only=None,
-            use_pristine_tar=True):
-        from . import dh_make
-        tree = dh_make.import_upstream(
-            tarball, package_name, version,
-            use_pristine_tar=use_pristine_tar)
-        if not bzr_only:
-            with tree.lock_write():
-                dh_make.run_dh_make(tree, package_name, version)
-        note(gettext('Package prepared in %s'),
-             urlutils.unescape_for_display(tree.basedir, self.outf.encoding))
-
-
 class cmd_dep3_patch(Command):
     """Format the changes in a branch as a DEP-3 patch.
 
@@ -1584,7 +1563,9 @@ class LocalTree(object):
         return False
 
 
-def _build_helper(local_tree, subpath, packaging_branch, target_dir, builder):
+def _build_helper(
+        local_tree, subpath, packaging_branch, target_dir, builder,
+        guess_upstream_branch_url=False):
     # TODO(jelmer): Integrate this with cmd_builddeb
     from .builder import (
         do_build,
@@ -1605,7 +1586,8 @@ def _build_helper(local_tree, subpath, packaging_branch, target_dir, builder):
             local_tree, subpath, packaging_branch, build_type=None,
             config=config, changelog=changelog,
             contains_upstream_source=contains_upstream_source,
-            top_level=top_level)
+            top_level=top_level,
+            guess_upstream_branch_url=guess_upstream_branch_url)
 
     return do_build(changelog.package, changelog.version, distiller,
                     local_tree, config, builder, target_dir)
