@@ -22,6 +22,8 @@
 
 from __future__ import absolute_import
 
+from email.message import Message
+
 from ... import (
     diff,
     errors,
@@ -33,10 +35,10 @@ from io import BytesIO
 import time
 
 
-def write_dep3_bug_line(f, bug_url, status):
+def write_dep3_bug_line(message, bug_url, status):
     """Write a DEP-3 compatible line with a bug link.
 
-    :param f: File-like object to write to
+    :param message: Message object to udpate
     :param bug_url: Bug URL
     :param status: Bug status (e.g. "fixed")
     """
@@ -44,13 +46,14 @@ def write_dep3_bug_line(f, bug_url, status):
     if status != "fixed":
         return
     if bug_url.startswith("http://bugs.debian.org/"):
-        f.write("Bug-Debian: %s\n" % bug_url)
+        message.add_header("Bug-Debian", bug_url)
     else:
         # FIXME: Filter out Ubuntu bugs on Launchpad
-        f.write("Bug: %s\n" % bug_url)
+        message.add_header("Bug", bug_url)
 
 
-def write_dep3_patch_header(f, description=None, origin=None, forwarded=None,
+def write_dep3_patch_header(
+        f, description=None, origin=None, forwarded=None,
         bugs=None, authors=None, revision_id=None, last_update=None,
         applied_upstream=None):
     """Write a DEP3 patch header.
@@ -67,37 +70,38 @@ def write_dep3_patch_header(f, description=None, origin=None, forwarded=None,
     :param applied_upstream: If the patch is applied upstream,
         an informal string describing where it was merged
     """
-    # FIXME: Handle line breaks, etc sensibly
+    header = Message()
     if description is not None:
         description = description.strip("\n")
         description = description.replace("\n\n", "\n.\n")
         description = description.replace("\n", "\n ")
-        f.write("Description: %s\n" % description)
+        header["Description"] = description
     if origin is not None:
-        f.write("Origin: %s\n" % origin)
+        header.add_header("Origin", origin)
     if forwarded is not None:
-        f.write("Forwarded: %s\n" % forwarded)
+        header.add_header("Forwarded", forwarded)
     if authors is not None:
         for author in authors:
-            f.write("Author: %s\n" % author)
+            header.add_header("Author", author)
     if bugs is not None:
         for bug_url, status in bugs:
-            write_dep3_bug_line(f, bug_url, status)
+            write_dep3_bug_line(header, bug_url, status)
     if last_update is not None:
-        f.write("Last-Update: %s\n" % time.strftime("%Y-%m-%d",
-                time.gmtime(last_update)))
+        header.add_header(
+            "Last-Update",
+            time.strftime("%Y-%m-%d", time.gmtime(last_update)))
     if applied_upstream is not None:
-        f.write("Applied-Upstream: %s\n" % applied_upstream)
+        header.add_header("Applied-Upstream", applied_upstream)
     if revision_id is not None:
         try:
             (foreign_revid, mapping) = foreign_vcs_registry.parse_revision_id(
                     revision_id)
         except errors.InvalidRevisionId:
-            f.write("X-Bzr-Revision-Id: %s\n" % revision_id.decode('utf-8'))
+            header.add_header("X-Bzr-Revision-Id", revision_id.decode('utf-8'))
         else:
             if mapping.vcs.abbreviation == "git":
-                f.write("X-Git-Commit: %s\n" % foreign_revid.decode('utf-8'))
-    f.write("\n")
+                header.add_header("X-Git-Commit", foreign_revid.decode('utf-8'))
+    f.write(str(header))
 
 
 def gather_bugs_and_authors(repository, interesting_revision_ids):
@@ -118,8 +122,8 @@ def gather_bugs_and_authors(repository, interesting_revision_ids):
     return (bugs, authors, last_update)
 
 
-def determine_applied_upstream(upstream_branch, feature_branch,
-        feature_revid=None):
+def determine_applied_upstream(
+        upstream_branch, feature_branch, feature_revid=None):
     """Check if a particular revision has been merged upstream.
 
     :param upstream_branch: Upstream branch object
@@ -132,8 +136,8 @@ def determine_applied_upstream(upstream_branch, feature_branch,
         feature_revid = feature_branch.last_revision()
     upstream_graph = feature_branch.repository.get_graph(
         upstream_branch.repository)
-    merger = upstream_graph.find_lefthand_merger(feature_revid,
-        upstream_branch.last_revision())
+    merger = upstream_graph.find_lefthand_merger(
+        feature_revid, upstream_branch.last_revision())
     if merger is not None:
         try:
             (foreign_revid, mapping) = foreign_vcs_registry.parse_revision_id(
@@ -144,8 +148,9 @@ def determine_applied_upstream(upstream_branch, feature_branch,
             if mapping.vcs.abbreviation == 'git':
                 return "merged in commit %s" % (
                     foreign_revid.decode('ascii')[:7], )
-        return "merged in revision %s" % (
-            ".".join(str(x) for x in upstream_branch.revision_id_to_dotted_revno(merger)), )
+        return "merged in revision %s" % (".".join(
+            str(x)
+            for x in upstream_branch.revision_id_to_dotted_revno(merger)), )
     else:
         return "no"
 
@@ -183,8 +188,8 @@ def describe_origin(branch, revid):
                 return "commit, %s, commit: %s" % (
                     public_branch_url, foreign_revid.decode('ascii')[:7], )
         return "commit, %s, revision: %s" % (
-            public_branch_url,
-            ".".join(str(x) for x in branch.revision_id_to_dotted_revno(revid)), )
+            public_branch_url, ".".join(
+                str(x) for x in branch.revision_id_to_dotted_revno(revid)), )
     else:
         try:
             (foreign_revid, mapping) = foreign_vcs_registry.parse_revision_id(
@@ -198,8 +203,8 @@ def describe_origin(branch, revid):
 
 
 def write_dep3_patch(f, branch, base_revid, target_revid, description=None,
-        origin=None, forwarded=None, applied_upstream=None, bugs=None,
-        authors=None, last_update=None):
+                     origin=None, forwarded=None, applied_upstream=None,
+                     bugs=None, authors=None, last_update=None):
     """Write a DEP-3 compliant patch.
 
     :param f: File-like object to write to
@@ -214,7 +219,8 @@ def write_dep3_patch(f, branch, base_revid, target_revid, description=None,
     :param authors: Sequence of authors of this patch
     :param last_update: Timestamp for last time this patch was updated
     """
-    write_dep3_patch_header(f, bugs=bugs, authors=authors,
+    write_dep3_patch_header(
+        f, bugs=bugs, authors=authors,
         last_update=last_update, description=description,
         revision_id=target_revid, origin=origin,
         applied_upstream=applied_upstream, forwarded=forwarded)
