@@ -30,12 +30,12 @@ from __future__ import absolute_import
 import calendar
 from contextlib import contextmanager, ExitStack
 import os
-import shutil
 import stat
 import tempfile
 
 from debian import deb822
 from debian.changelog import Version, Changelog, VersionError
+from debmutate.versions import mangle_version_for_git
 
 from ... import (
     controldir,
@@ -62,8 +62,6 @@ from ...transport import (
 from .bzrtools_import import import_dir
 from .errors import (
     MultipleUpstreamTarballsNotSupported,
-    UpstreamAlreadyImported,
-    UpstreamBranchAlreadyMerged,
     )
 from .extract import extract
 from .util import (
@@ -82,6 +80,17 @@ from .upstream.pristinetar import (
     )
 
 
+class UpstreamBranchAlreadyMerged(BzrError):
+    _fmt = 'That revision of the upstream branch has already been merged.'
+
+
+class UpstreamAlreadyImported(BzrError):
+    _fmt = 'Upstream version "%(version)s" has already been imported.'
+
+    def __init__(self, version):
+        BzrError.__init__(self, version=str(version))
+
+
 class PreviousVersionTagMissing(BzrError):
 
     _fmt = ("Unable to find the tag for the "
@@ -322,6 +331,7 @@ class DistributionBranch(object):
         :return: True if this branch contains the specified version of the
             package. False otherwise.
         """
+        version = mangle_version(self.branch, str(version))
         if branch_has_debian_version(self.branch, str(version), md5=md5):
             return True
         # TODO(jelmer): There is some overlap here with revid_of_version
@@ -331,6 +341,9 @@ class DistributionBranch(object):
         for ubuntu_tag_name in ["ubuntu-%s" % version, "ubuntu/%s" % version]:
             if branch_has_debian_version(self.branch, ubuntu_tag_name, md5=md5):
                 return True
+        for other_tag_name in ["v%s" % version]:
+            if branch_has_debian_version(self.branch, other_tag_name, md5=md5):
+                return True
         return False
 
     def contained_versions(self, versions):
@@ -410,12 +423,16 @@ class DistributionBranch(object):
         """
         if branch_has_debian_version(self.branch, str(version)):
             return self.branch.tags.lookup_tag(str(version))
+        version = mangle_version(self.branch, str(version))
         for debian_tag_name in ["debian-%s" % version, "debian/%s" % version]:
             if branch_has_debian_version(self.branch, debian_tag_name):
                 return self.branch.tags.lookup_tag(debian_tag_name)
         for ubuntu_tag_name in ["ubuntu-%s" % version, "ubuntu/%s" % version]:
             if branch_has_debian_version(self.branch, ubuntu_tag_name):
                 return self.branch.tags.lookup_tag(ubuntu_tag_name)
+        for other_tag_name in ["v%s" % version]:
+            if branch_has_debian_version(self.branch, other_tag_name):
+                return self.branch.tags.lookup_tag(other_tag_name)
         return self.branch.tags.lookup_tag(str(version))
 
     def tag_version(self, version, revid=None, vendor=None):
@@ -749,7 +766,7 @@ class DistributionBranch(object):
         # Make sure we see any revisions added by the upstream branch
         # since self.tree was locked.
         self.branch.repository.refresh_data()
-        for (component, tag, revid) in imported_revids:
+        for (component, tag, revid, pristine_tar_imported) in imported_revids:
             self.branch.fetch(self.pristine_upstream_branch, revid)
         self.pristine_upstream_branch.tags.merge_to(self.branch.tags)
 
@@ -770,7 +787,8 @@ class DistributionBranch(object):
         :param upstream_parents: the parents to give the upstream revision
         :param timestamp: a tuple of (timestamp, timezone) to use for
             the commit, or None to use the current time.
-        :return: list with (component, tag, revid) tuples
+        :return:
+            list with (component, tag, revid, pristine_tar_imported) tuples
         """
         # Should we just dump the upstream part on whatever is currently
         # there, or try and pull all of the other upstream versions
@@ -813,7 +831,7 @@ class DistributionBranch(object):
                 upstream_trees = file_ids_from + upstream_trees
             if self.tree:
                 self_tree = self.tree
-                self_tree.lock_write()  # might also be upstream tree for dh_make
+                self_tree.lock_write()
             else:
                 self_tree = self.branch.basis_tree()
                 self_tree.lock_read()
@@ -840,14 +858,14 @@ class DistributionBranch(object):
                     tb[1] for tb in upstream_tarballs if tb[1] is not None]
             else:
                 exclude = []
-            (tag, revid) = self.pristine_upstream_source.import_component_tarball(
+            (tag, revid, pristine_tar_imported) = self.pristine_upstream_source.import_component_tarball(
                 package, version, self.pristine_upstream_tree, parents,
                 component, md5, tarball, author=author, timestamp=timestamp,
                 exclude=exclude, force_pristine_tar=force_pristine_tar,
                 committer=committer, files_excluded=files_excluded,
                 reuse_existing=True)
             self.pristine_upstream_branch.generate_revision_history(revid)
-            ret.append((component, tag, revid))
+            ret.append((component, tag, revid, pristine_tar_imported))
             self.branch.fetch(self.pristine_upstream_branch)
             self.branch.tags.set_tag(tag, revid)
         return ret
@@ -867,7 +885,8 @@ class DistributionBranch(object):
             tarball.
         :param upstream_revisions: Upstream revision ids dictionary
         :param md5sum: hex digest of the md5sum of the tarball, if known.
-        :return: list with (component, tag, revid) tuples
+        :return: list with (component, tag, revid, pristine_tar_imported)
+            tuples
         """
         with _extract_tarballs_to_tempdir(tarballs) as tarball_dir:
             return self.import_upstream(
@@ -1353,7 +1372,7 @@ class DistributionBranch(object):
                 conflicts = 0
                 self.tree.pull(self.pristine_upstream_branch)
             self.pristine_upstream_branch.tags.merge_to(self.branch.tags)
-            return conflicts
+            return conflicts, imported_revids
 
 
 @contextmanager
@@ -1417,6 +1436,13 @@ def _default_config_for_tree(tree):
     return fileid, path, config
 
 
+def mangle_version(branch, version):
+    git = getattr(branch.repository, '_git', None)
+    if git:
+        return mangle_version_for_git(version)
+    return version
+
+
 def branch_has_debian_version(branch, tag_name, md5=None):
     if not branch.tags.has_tag(tag_name):
         return False
