@@ -22,7 +22,6 @@ import errno
 import logging
 import os.path
 import re
-import shutil
 import subprocess
 import tempfile
 
@@ -44,16 +43,15 @@ class ChangeLogFileMerge(merge.ConfigurableFileMerger):
     default_files = ['debian/changelog']
 
     def merge_text(self, params):
-        return merge_changelog(params.this_lines, params.other_lines,
-            params.base_lines)
+        return merge_changelog(
+            params.this_lines, params.other_lines, params.base_lines)
 
 
 def merge_changelog(this_lines, other_lines, base_lines=[]):
     """Merge a changelog file."""
     # Write the BASE, THIS and OTHER versions to files in a temporary
     # directory, and use dpkg-mergechangelogs to merge them.
-    tmpdir = tempfile.mkdtemp('deb_changelog_merge')
-    try:
+    with tempfile.TemporaryDirectory('deb_changelog_merge') as tmpdir:
         def writelines(filename, lines):
             with open(filename, 'wb') as f:
                 for line in lines:
@@ -65,8 +63,9 @@ def merge_changelog(this_lines, other_lines, base_lines=[]):
         writelines(this_filename, this_lines)
         writelines(other_filename, other_lines)
         try:
-            proc = subprocess.Popen(['dpkg-mergechangelogs', base_filename,
-                this_filename, other_filename], stdout=subprocess.PIPE,
+            proc = subprocess.Popen(
+                ['dpkg-mergechangelogs', base_filename, this_filename,
+                 other_filename], stdout=subprocess.PIPE,
                 stderr=subprocess.PIPE)
         except OSError as e:
             if e.errno == errno.ENOENT:
@@ -105,9 +104,8 @@ def merge_changelog(this_lines, other_lines, base_lines=[]):
             # dpkg-mergechangelogs exited with an error. There is probably no
             # output at all, but regardless the merge should fall back to
             # another method.
-            _logger.warning("dpkg-mergechangelogs failed with status %d", retcode)
+            _logger.warning(
+                "dpkg-mergechangelogs failed with status %d", retcode)
             return 'not_applicable', stdout.splitlines(True)
         else:
             return 'success', stdout.splitlines(True)
-    finally:
-        shutil.rmtree(tmpdir)
