@@ -38,13 +38,13 @@ from ... import osutils
 from ...revision import NULL_REVISION
 
 from .errors import (
-    DchError,
-    UpstreamAlreadyImported,
+    BzrError,
     )
 from .import_dsc import (
     DistributionBranch,
     DistributionBranchSet,
     PreviousVersionTagMissing,
+    UpstreamAlreadyImported,
     )
 from .repack_tarball import repack_tarball
 from .util import (
@@ -59,6 +59,13 @@ from .util import (
 TAG_PREFIX = "upstream-"
 
 
+class DchError(BzrError):
+    _fmt = 'There was an error using dch: %(error)s.'
+
+    def __init__(self, error):
+        BzrError.__init__(self, error=error)
+
+
 def package_version(upstream_version, distribution_name, epoch=None):
     """Determine the package version for a new upstream.
 
@@ -229,8 +236,8 @@ def fetch_tarball(package, version, orig_dir, locations, v3):
     return ret
 
 
-def get_tarballs(orig_dir, tree, package, version, upstream_branch,
-                 upstream_revision, locations):
+def get_tarballs(orig_dir, tree, package, version, locations):
+    """Retrieve upstream tarballs."""
     source_format = tree_get_source_format(tree)
     v3 = (source_format in [FORMAT_3_0_QUILT, FORMAT_3_0_NATIVE])
     orig_dir = os.path.join(tree.basedir, orig_dir)
