@@ -18,10 +18,17 @@
 #    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #
 
+import os
+import shlex
 import subprocess
+import sys
+
+from debmutate.changelog import release as mark_for_release, ChangelogEditor
 
 from ... import osutils
 
+from .changelog import debcommit_release
+
 from .util import (
     find_changelog,
     )
@@ -39,12 +46,9 @@ def release(local_tree, subpath):
             changelog_path = 'changelog'
         else:
             changelog_path = 'debian/changelog'
-        changelog_arg = "--changelog=%s" % changelog_path
-        # TODO(jelmer): don't send output to stderr
-        cwd = osutils.pathjoin(local_tree.basedir, subpath)
-        subprocess.check_call(
-            ["dch", changelog_arg, "--release", ""],
-            cwd=cwd)
-        subprocess.check_call(
-            ["debcommit", changelog_arg, "-ar"],
-            cwd=cwd)
+        changelog_abspath = local_tree.abspath(
+            os.path.join(subpath, changelog_path))
+        with ChangelogEditor(changelog_abspath) as e:
+            mark_for_release(e.changelog)
+        return debcommit_release(local_tree, subpath=subpath)
+    return None
