@@ -27,7 +27,7 @@ from ....errors import (
     FileExists,
     )
 
-from ..errors import MissingUpstreamTarball
+from ..upstream import MissingUpstreamTarball
 from ..source_distiller import (
     FullSourceDistiller,
     MergeModeDistiller,
@@ -50,7 +50,7 @@ class NativeSourceDistillerTests(TestCaseWithTransport):
         wt = self.make_branch_and_tree(".")
         wt.lock_read()
         self.addCleanup(wt.unlock)
-        sd = NativeSourceDistiller(wt)
+        sd = NativeSourceDistiller(wt, '')
         self.build_tree(['target/'])
         self.assertRaises(FileExists, sd.distill, 'target')
 
@@ -60,24 +60,24 @@ class NativeSourceDistillerTests(TestCaseWithTransport):
         wt.lock_write()
         self.addCleanup(wt.unlock)
         wt.add(['a'])
-        revid = wt.commit("one")
+        wt.commit("one")
         rev_tree = wt.basis_tree()
-        sd = NativeSourceDistiller(rev_tree)
+        sd = NativeSourceDistiller(rev_tree, '')
         sd.distill('target')
         self.assertPathExists('target')
         self.assertPathExists('target/a')
 
     def test_distill_removes_builddeb_dir(self):
         wt = self.make_branch_and_tree(".")
-        self.build_tree(['a', '.bzr-builddeb/',
-                '.bzr-builddeb/default.conf'])
+        self.build_tree(
+            ['a', '.bzr-builddeb/', '.bzr-builddeb/default.conf'])
         wt.lock_write()
         self.addCleanup(wt.unlock)
         wt.add(['a', '.bzr-builddeb/',
                 '.bzr-builddeb/default.conf'])
-        revid = wt.commit("one")
+        wt.commit("one")
         rev_tree = wt.basis_tree()
-        sd = NativeSourceDistiller(rev_tree)
+        sd = NativeSourceDistiller(rev_tree, '')
         sd.distill('target')
         self.assertPathExists('target')
         self.assertPathExists('target/a')
@@ -90,7 +90,7 @@ class NativeSourceDistillerTests(TestCaseWithTransport):
         wt.lock_write()
         self.addCleanup(wt.unlock)
         wt.add(['a', 'b'])
-        sd = NativeSourceDistiller(wt)
+        sd = NativeSourceDistiller(wt, '')
         sd.distill('target')
         self.assertPathExists('target')
         self.assertPathExists('target/a')
@@ -103,7 +103,7 @@ class FullSourceDistillerTests(TestCaseWithTransport):
         wt = self.make_branch_and_tree(".")
         wt.lock_read()
         self.addCleanup(wt.unlock)
-        sd = FullSourceDistiller(wt, None)
+        sd = FullSourceDistiller(wt, '', None)
         self.build_tree(['target/'])
         self.assertRaises(FileExists, sd.distill, 'target')
 
@@ -111,14 +111,14 @@ class FullSourceDistillerTests(TestCaseWithTransport):
         wt = self.make_branch_and_tree(".")
         wt.lock_read()
         self.addCleanup(wt.unlock)
-        sd = FullSourceDistiller(wt, _MissingUpstreamProvider())
+        sd = FullSourceDistiller(wt, '', _MissingUpstreamProvider())
         self.assertRaises(MissingUpstreamTarball, sd.distill, 'target')
 
     def test_distill_tarball_exists(self):
         wt = self.make_branch_and_tree(".")
         wt.lock_read()
         self.addCleanup(wt.unlock)
-        sd = FullSourceDistiller(wt, _TouchUpstreamProvider('tarball'))
+        sd = FullSourceDistiller(wt, '', _TouchUpstreamProvider('tarball'))
         sd.distill('target')
         self.assertPathExists('tarball')
 
@@ -128,7 +128,7 @@ class FullSourceDistillerTests(TestCaseWithTransport):
         self.addCleanup(wt.unlock)
         self.build_tree(['a', '.bzr-builddeb'])
         wt.add(['a', '.bzr-builddeb'])
-        sd = FullSourceDistiller(wt, _TouchUpstreamProvider('tarball'))
+        sd = FullSourceDistiller(wt, '', _TouchUpstreamProvider('tarball'))
         sd.distill('target')
         self.assertPathExists('tarball')
         self.assertPathExists('target')
@@ -142,7 +142,7 @@ class FullSourceDistillerTests(TestCaseWithTransport):
         wt.lock_write()
         self.addCleanup(wt.unlock)
         wt.add(['a', 'b'])
-        sd = FullSourceDistiller(wt, _TouchUpstreamProvider('tarball'))
+        sd = FullSourceDistiller(wt, '', _TouchUpstreamProvider('tarball'))
         sd.distill('target')
         self.assertPathExists('target')
         self.assertPathExists('target/a')
@@ -161,7 +161,7 @@ class MergeModeDistillerTests(TestCaseWithTransport):
         wt = self.make_branch_and_tree(".")
         wt.lock_read()
         self.addCleanup(wt.unlock)
-        sd = MergeModeDistiller(wt, None)
+        sd = MergeModeDistiller(wt, '', None)
         self.build_tree(['target/'])
         self.assertRaises(FileExists, sd.distill, 'target')
 
@@ -169,8 +169,8 @@ class MergeModeDistillerTests(TestCaseWithTransport):
         wt = self.make_branch_and_tree(".")
         wt.lock_read()
         self.addCleanup(wt.unlock)
-        sd = MergeModeDistiller(wt, _SimpleUpstreamProvider("package",
-                    "0.1-1", "tarballs"))
+        sd = MergeModeDistiller(
+            wt, '', _SimpleUpstreamProvider("package", "0.1-1", "tarballs"))
         self.assertRaises(MissingUpstreamTarball, sd.distill, 'target')
 
     def test_distill_tarball_exists(self):
@@ -180,11 +180,11 @@ class MergeModeDistillerTests(TestCaseWithTransport):
         name = "package"
         version = Version("0.1-1")
         self.make_tarball(name, version)
-        sd = MergeModeDistiller(wt, _SimpleUpstreamProvider(name,
-                    version.upstream_version, "."))
+        sd = MergeModeDistiller(
+            wt, '', _SimpleUpstreamProvider(name, version.upstream_version, "."))
         sd.distill('target/foo')
-        self.assertPathExists('target/%s_%s.orig.tar.gz'
-                % (name, version.upstream_version))
+        self.assertPathExists(
+            'target/%s_%s.orig.tar.gz' % (name, version.upstream_version))
         self.assertPathExists('target/foo/a')
 
     def test_distill_exports_branch(self):
@@ -196,8 +196,8 @@ class MergeModeDistillerTests(TestCaseWithTransport):
         name = "package"
         version = Version("0.1-1")
         self.make_tarball(name, version)
-        sd = MergeModeDistiller(wt, _SimpleUpstreamProvider(name,
-                    version.upstream_version, "."))
+        sd = MergeModeDistiller(
+            wt, '', _SimpleUpstreamProvider(name, version.upstream_version, "."))
         sd.distill('target/')
         self.assertPathExists('target/debian/a')
         self.assertPathDoesNotExist('target/.bzr-builddeb')
@@ -215,8 +215,8 @@ class MergeModeDistillerTests(TestCaseWithTransport):
         builder.add_upstream_file("debian/foo")
         builder.add_default_control()
         builder.build()
-        sd = MergeModeDistiller(wt, _SimpleUpstreamProvider(name,
-                    version.upstream_version, "."))
+        sd = MergeModeDistiller(
+            wt, '', _SimpleUpstreamProvider(name, version.upstream_version, "."))
         sd.distill('target/')
         self.assertPathExists('target/a')
         self.assertPathDoesNotExist('target/debian/foo')
@@ -230,8 +230,9 @@ class MergeModeDistillerTests(TestCaseWithTransport):
         name = "package"
         version = Version("0.1-1")
         self.make_tarball(name, version)
-        sd = MergeModeDistiller(wt, _SimpleUpstreamProvider(name,
-                    version.upstream_version, "."), top_level=True)
+        sd = MergeModeDistiller(
+            wt, '', _SimpleUpstreamProvider(name, version.upstream_version, "."),
+            top_level=True)
         sd.distill('target/')
         self.assertPathExists('target/a')
         self.assertPathExists('target/debian/b')
@@ -248,10 +249,11 @@ class MergeModeDistillerTests(TestCaseWithTransport):
         name = "package"
         version = Version("0.1-1")
         self.make_tarball(name, version)
-        sd = MergeModeDistiller(wt, _SimpleUpstreamProvider(name,
-                    version.upstream_version, "."), use_existing=True)
-        self.build_tree(['target/', 'target/b', 'target/debian/',
-                'target/debian/b'])
+        sd = MergeModeDistiller(
+            wt, '', _SimpleUpstreamProvider(name, version.upstream_version, "."),
+            use_existing=True)
+        self.build_tree(
+            ['target/', 'target/b', 'target/debian/', 'target/debian/b'])
         sd.distill('target/')
         self.assertPathExists('target/b')
         self.assertPathExists('target/debian/a')
@@ -268,8 +270,8 @@ class MergeModeDistillerTests(TestCaseWithTransport):
         name = "package"
         version = Version("0.1-1")
         self.make_tarball(name, version)
-        sd = MergeModeDistiller(wt, _SimpleUpstreamProvider(name,
-                    version.upstream_version, "."))
+        sd = MergeModeDistiller(
+            wt, '', _SimpleUpstreamProvider(name, version.upstream_version, "."))
         sd.distill('target')
         self.assertPathExists('target')
         self.assertPathExists('target/debian/a')
