@@ -389,6 +389,11 @@ class GuessUpstreamRevspecTests(TestCase):
                 [u'tag:1.2', u'tag:foo-1.2', u'tag:v1.2', u'tag:v.1.2'],
                 list(guess_upstream_revspec('foo', '1.2')))
 
+    def test_guess_upstream_revspec_ds(self):
+        self.assertEqual(
+                [u'tag:1.2', u'tag:foo-1.2', u'tag:v1.2', u'tag:v.1.2'],
+                list(guess_upstream_revspec('foo', '1.2+ds')))
+
     def test_snapshot(self):
         self.assertEqual(
                 [u'revno:1200', u'tag:1.2+bzr1200', u'tag:foo-1.2+bzr1200',
@@ -450,8 +455,10 @@ class UpstreamBranchSourceTests(TestCaseWithTransport):
         self.assertEquals("2.1+bzr2", source.get_latest_version("foo", "1.0"))
 
     def test_get_latest_version_not_snapshot(self):
-        self.tree.commit("msg")
-        self.tree.branch.tags.set_tag("2.1", self.tree.branch.last_revision())
+        revid1 = self.tree.commit("msg")
+        revid2 = self.tree.commit("msg")
+        self.tree.branch.tags.set_tag("1.0", revid1)
+        self.tree.branch.tags.set_tag("2.1", revid2)
         source = UpstreamBranchSource(self.tree.branch,
             {"2.1": self.tree.branch.last_revision().decode('utf-8')},
             snapshot=False)
@@ -460,8 +467,10 @@ class UpstreamBranchSourceTests(TestCaseWithTransport):
         self.assertEquals("2.1", source.get_latest_version("foo", "1.0"))
 
     def test_get_recent_versions(self):
-        self.tree.commit("msg")
-        self.tree.branch.tags.set_tag("2.1", self.tree.branch.last_revision())
+        revid1 = self.tree.commit("msg")
+        self.tree.branch.tags.set_tag("1.0", revid1)
+        revid2 = self.tree.commit("msg")
+        self.tree.branch.tags.set_tag("2.1", revid2)
         source = UpstreamBranchSource(
             self.tree.branch,
             {"2.1": self.tree.branch.last_revision().decode('utf-8')})
@@ -587,14 +596,16 @@ class LazyUpstreamBranchSourceTests(TestCaseWithTransport):
 
     def test_get_recent_versions(self):
         revid1 = self.tree.commit("msg")
-        self.tree.branch.tags.set_tag("2.1", revid1)
+        self.tree.branch.tags.set_tag("1.0", revid1)
+        revid2 = self.tree.commit("msg")
+        self.tree.branch.tags.set_tag("2.1", revid2)
         source = LazyUpstreamBranchSource(
             self.tree.branch.base,
             {"2.1": self.tree.branch.last_revision()})
         self.assertIs(None, source._upstream_branch)
         self.assertEquals(["2.1"], source.get_recent_versions("foo", "1.0"))
-        revid2 = self.tree.commit("msg")
-        self.tree.branch.tags.set_tag("2.2", revid2)
+        revid3 = self.tree.commit("msg")
+        self.tree.branch.tags.set_tag("2.2", revid3)
         self.assertEquals(
             ["2.1", "2.2"],
             source.get_recent_versions("foo", "1.0"))
