@@ -35,11 +35,6 @@ from ..config import (
     BUILD_TYPE_NATIVE,
     BUILD_TYPE_NORMAL,
     )
-from ..errors import (
-    AddChangelogError,
-    InconsistentSourceFormatError,
-    NoPreviousUpload,
-    )
 from . import (
     LzmaFeature,
     SourcePackageBuilder,
@@ -47,6 +42,9 @@ from . import (
     TestCaseWithTransport,
     )
 from ..util import (
+    AddChangelogError,
+    InconsistentSourceFormatError,
+    NoPreviousUpload,
     changelog_find_previous_upload,
     component_from_orig_tarball,
     dget,
@@ -55,7 +53,6 @@ from ..util import (
     find_bugs_fixed,
     find_changelog,
     find_extra_authors,
-    find_last_distribution,
     find_thanks,
     get_build_architecture,
     get_files_excluded,
@@ -665,35 +662,6 @@ class MockLaunchpad(object):
             return []
 
 
-class FindLastDistributionTests(TestCase):
-
-    def create_changelog(self, *distributions):
-        changelog = Changelog()
-        changes = ["  [ A. Hacker ]", "  * Something"]
-        author = "J. Maintainer <maint@example.com"
-        for distro in distributions:
-            changelog.new_block(changes=changes, author=author,
-                                distributions=distro)
-        return changelog
-
-    def test_first(self):
-        changelog = self.create_changelog("unstable")
-        self.assertEquals("unstable", find_last_distribution(changelog))
-
-    def test_second(self):
-        changelog = self.create_changelog("unstable", "UNRELEASED")
-        self.assertEquals("UNRELEASED", changelog.distributions)
-        self.assertEquals("unstable", find_last_distribution(changelog))
-
-    def test_empty(self):
-        changelog = self.create_changelog()
-        self.assertEquals(None, find_last_distribution(changelog))
-
-    def test_only_unreleased(self):
-        changelog = self.create_changelog("UNRELEASED")
-        self.assertEquals(None, find_last_distribution(changelog))
-
-
 class FindPreviousUploadTests(TestCase):
 
     def make_changelog(self, versions_and_distributions):
