@@ -24,6 +24,8 @@ import re
 import subprocess
 import tempfile
 
+from debmutate.versions import git_snapshot_data_from_version
+
 from .... import osutils
 from ....branch import (
     Branch,
@@ -322,29 +324,10 @@ def get_export_upstream_revision(config=None, version=None):
     return rev
 
 
-def git_snapshot_data_from_version(version):
-    git_id = None
-    date = None
-    if "+git" in version or "~git" in version or "-git" in version:
-        m = re.match(
-            ".*[~+-]git([0-9]{4})([0-9]{2})([0-9]{2})\\.([0-9a-f]{7}).*",
-            version)
-        if not m:
-            m = re.match(
-                ".*[~+-]git([0-9]{4})([0-9]{2})([0-9]{2})\\.[0-9+]\\.([0-9a-f]{7}).*",
-                version)
-        if m:
-            git_id = m.group(4)
-            date = "%s-%s-%s" % (m.group(1), m.group(2), m.group(3))
-        else:
-            m = re.match(".*[~+]git([0-9]{4})([0-9]{2})([0-9]{2}).*", version)
-            if m:
-                date = "%s-%s-%s" % (m.group(1), m.group(2), m.group(3))
-    return (git_id, date)
-
-
 def guess_upstream_revspec(package, version):
     """Guess revspecs matching an upstream version string."""
+    if version.endswith('+ds'):
+        version = str(version)[:-len('+ds')]
     if "+bzr" in version or "~bzr" in version:
         yield "revno:%s" % re.match(".*[~+]bzr(\\d+).*", version).group(1)
     (git_id, git_date) = git_snapshot_data_from_version(version)
@@ -353,6 +336,9 @@ def guess_upstream_revspec(package, version):
     if git_date:
         yield "date:%s" % git_date
     yield 'tag:%s' % version
+    for prefix in ['rust-']:
+        if package.startswith(prefix):
+            yield 'tag:%s-%s' % (package[len(prefix):], version)
     yield 'tag:%s-%s' % (package, version)
     yield 'tag:v%s' % version
     yield 'tag:v.%s' % version
@@ -527,13 +513,23 @@ class UpstreamBranchSource(UpstreamSource):
     def get_recent_versions(self, package, since_version=None):
         versions = []
         tags = self.upstream_branch.tags.get_tag_dict()
-        for tag, revision in tags.items():
-            version = upstream_tag_to_version(tag, package)
-            if version is None:
-                continue
-            if since_version is not None and version <= since_version:
-                continue
-            versions.append(version)
+        with self.upstream_branch.repository.lock_read():
+            graph = self.upstream_branch.repository.get_graph()
+            if since_version is not None:
+                since_revision = self.version_as_revision(
+                    package, since_version)
+            else:
+                since_revision = None
+            for tag, revision in tags.items():
+                version = upstream_tag_to_version(tag, package)
+                if version is None:
+                    continue
+                if since_version is not None and version <= since_version:
+                    continue
+                if since_revision and not graph.is_ancestor(
+                        since_revision, revision):
+                    continue
+                versions.append(version)
         return sorted(versions)
 
     def get_version(self, package, current_version, revision):
@@ -610,6 +606,8 @@ class LazyUpstreamBranchSource(UpstreamBranchSource):
     @property
     def upstream_branch(self):
         if self._upstream_branch is None:
+            if callable(self.upstream_branch_url):
+                self.upstream_branch_url = self.upstream_branch_url()
             self._upstream_branch = Branch.open(self.upstream_branch_url)
         return self._upstream_branch
 
