@@ -52,6 +52,7 @@ from .... import (
 from ....commit import NullCommitReporter
 from ....errors import (
     BzrError,
+    DivergedBranches,
     NoSuchRevision,
     NoSuchTag,
     NoSuchFile,
@@ -72,7 +73,6 @@ from .branch import (
 from .tags import (
     GbpTagFormatError,
     gbp_expand_tag_name,
-    mangle_version_for_git,
     upstream_tag_name,
     is_upstream_tag,
     possible_upstream_tag_names,
@@ -80,6 +80,7 @@ from .tags import (
     upstream_version_tag_start_revids,
     upstream_tag_version,
     )
+from debmutate.versions import mangle_version_for_git
 
 
 class PristineTarError(BzrError):
@@ -363,7 +364,8 @@ class BasePristineTarSource(UpstreamSource):
                     return RevisionSpec.from_string('git:%s' % git_id).as_revision_id(self.branch)
                 except (InvalidRevisionSpec, NoSuchTag):
                     pass
-            revid = self._search_for_upstream_version(package, version, component, md5)
+            revid = self._search_for_upstream_version(
+                package, version, component, md5)
             tag_name = self.tag_name(version, component=component)
             if revid is not None:
                 warning(
@@ -376,7 +378,8 @@ class BasePristineTarSource(UpstreamSource):
             except NoSuchTag:
                 raise PackageVersionNotPresent(package, version, self)
 
-    def _search_for_upstream_version(self, package, version, component, md5=None):
+    def _search_for_upstream_version(
+            self, package, version, component, md5=None):
         raise NotImplementedError(self._search_for_upstream_version)
 
     def has_version_component(self, package, version, component, md5=None):
@@ -472,6 +475,7 @@ class BzrPristineTarSource(BasePristineTarSource):
             else:
                 warning('Not setting pristine tar revision properties '
                         'since the repository does not support it.')
+                delta = None
         else:
             delta = None
         if author is not None:
@@ -504,7 +508,7 @@ class BzrPristineTarSource(BasePristineTarSource):
         mutter(
             'imported %s version %s component %r as revid %s, tagged %s',
             package, version, component, revid, tag_name)
-        return tag_name, revid
+        return tag_name, revid, delta is not None
 
     def fetch_component_tarball(self, package, version, component, target_dir):
         revid = self.version_component_as_revision(package, version, component)
@@ -582,7 +586,8 @@ class BzrPristineTarSource(BasePristineTarSource):
                 package, version, component, target_dir)
             for component in components]
 
-    def _search_for_upstream_version(self, package, version, component, md5=None):
+    def _search_for_upstream_version(
+            self, package, version, component, md5=None):
         start_revids = []
         sources = []
         sources.append('main branch')
@@ -602,7 +607,7 @@ class BzrPristineTarSource(BasePristineTarSource):
 def get_pristine_tar_source(packaging_tree, packaging_branch):
     git = getattr(packaging_branch.repository, '_git', None)
     if git:
-        return GitPristineTarSource.from_tree(packaging_tree)
+        return GitPristineTarSource.from_tree(packaging_tree, packaging_branch)
     return BzrPristineTarSource(packaging_branch)
 
 
@@ -656,7 +661,7 @@ class GitPristineTarSource(BasePristineTarSource):
         return "<%s at %s>" % (self.__class__.__name__, self.branch.base)
 
     @classmethod
-    def from_tree(cls, tree):
+    def from_tree(cls, tree, packaging_branch=None):
         if tree and tree.has_filename('debian/gbp.conf'):
             parser = configparser.ConfigParser(defaults={
                 'pristine-tar': 'false',
@@ -696,7 +701,7 @@ class GitPristineTarSource(BasePristineTarSource):
         except NotBranchError:
             branch = tree.controldir.create_branch(upstream_branch)
         return cls(branch, gbp_tag_format, pristine_tar,
-                   packaging_branch=getattr(tree, 'branch', None))
+                   packaging_branch=packaging_branch)
 
     def tag_name(self, version, component=None, distro=None):
         """Gets the tag name for the upstream part of version.
@@ -780,7 +785,20 @@ class GitPristineTarSource(BasePristineTarSource):
             tree.branch.tags.set_tag(tag_name, revid)
             tree.update_basis_by_delta(revid, builder.get_basis_delta())
         revtree = tree.branch.repository.revision_tree(revid)
-        self.branch.pull(tree.branch, stop_revision=revid)
+        try:
+            self.branch.pull(tree.branch, stop_revision=revid)
+        except DivergedBranches:
+            warning('Upstream version %s (%s) is older than current tip.',
+                    version, tag_name)
+            with tree.lock_write():
+                builder = tree.branch.get_commit_builder(
+                    parents=[tree.branch.last_revision(), revid],
+                    committer=committer)
+                list(builder.record_iter_changes(
+                    tree, tree.branch.last_revision(), []))
+                builder.finish_inventory()
+                builder.commit('Merge %s.' % version)
+
         tree_id = revtree._lookup_path(u'')[2]
         try:
             pristine_tar_branch = self.branch.controldir.open_branch(
@@ -805,15 +823,18 @@ class GitPristineTarSource(BasePristineTarSource):
             except PristineTarDeltaExists:
                 if reuse_existing:
                     note('Reusing existing tarball, since delta exists.')
-                    return tag_name, revid
+                    return tag_name, revid, True
                 raise
             else:
                 note('Imported %s with pristine-tar.',
                      os.path.basename(tarball))
+                pristine_tar_imported = True
+        else:
+            pristine_tar_imported = False
         mutter(
             'imported %s version %s component %r as revid %s, tagged %s',
             package, version, component, revid, tag_name)
-        return tag_name, revid
+        return tag_name, revid, pristine_tar_imported
 
     def fetch_component_tarball(self, package, version, component, target_dir):
         note("Using pristine-tar to reconstruct %s/%s.", package, version)
