@@ -33,7 +33,13 @@ from debian import deb822
 from debian.changelog import Changelog, ChangelogParseError
 from debian.copyright import Copyright, NotMachineReadableError
 
-from debmutate.changelog import strip_changelog_message
+from debmutate.changelog import (
+    changes_by_author,
+    find_thanks,
+    find_extra_authors,
+    find_last_distribution,
+    strip_changelog_message,
+    )
 
 from ... import (
     bugtracker,
@@ -61,11 +67,6 @@ from .config import (
     )
 from .errors import (
     BzrError,
-    AddChangelogError,
-    InconsistentSourceFormatError,
-    NoPreviousUpload,
-    UnableToFindPreviousUpload,
-    UnparseableChangelog,
     )
 
 BUILDDEB_DIR = '.bzr-builddeb'
@@ -162,6 +163,13 @@ def recursive_copy(fromdir, todir):
                 shutil.copy(path, todir)
 
 
+class AddChangelogError(BzrError):
+    _fmt = 'Please add "%(changelog)s" to the branch using bzr add.'
+
+    def __init__(self, changelog):
+        BzrError.__init__(self, changelog=changelog)
+
+
 def find_changelog(t, subpath='', merge=False, max_blocks=1):
     """Find the changelog in the given tree.
 
@@ -219,11 +227,8 @@ def find_changelog(t, subpath='', merge=False, max_blocks=1):
             raise AddChangelogError(changelog_file)
         contents = t.get_file_text(changelog_file)
     changelog = Changelog()
-    try:
-        changelog.parse_changelog(
-            contents, max_blocks=max_blocks, allow_empty_author=True)
-    except ChangelogParseError as e:
-        raise UnparseableChangelog(str(e))
+    changelog.parse_changelog(
+        contents, max_blocks=max_blocks, allow_empty_author=True)
     return changelog, top_level
 
 
@@ -432,10 +437,10 @@ def find_bugs_fixed(changes, branch, _lplib=None):
     if _lplib is None:
         from . import launchpad as _lplib
     bugs = []
-    for change in changes:
+    for new_author, linenos, lines in changes_by_author(changes):
         for match in re.finditer(
                 "closes:\\s*(?:bug)?\\#?\\s?\\d+"
-                "(?:,\\s*(?:bug)?\\#?\\s?\\d+)*", change,
+                "(?:,\\s*(?:bug)?\\#?\\s?\\d+)*", ''.join(lines),
                 re.IGNORECASE):
             closes_list = match.group(0)
             for match in re.finditer("\\d+", closes_list):
@@ -446,7 +451,8 @@ def find_bugs_fixed(changes, branch, _lplib=None):
                     bug_url = bugtracker.get_bug_url("lp", branch, lp_bugs[0])
                     bugs.append(bug_url + " fixed")
         for match in re.finditer(
-                "lp:\\s+\\#\\d+(?:,\\s*\\#\\d+)*", change, re.IGNORECASE):
+                "lp:\\s+\\#\\d+(?:,\\s*\\#\\d+)*",
+                ''.join(lines), re.IGNORECASE):
             closes_list = match.group(0)
             for match in re.finditer("\\d+", closes_list):
                 bug_url = bugtracker.get_bug_url("lp", branch, match.group(0))
@@ -459,50 +465,6 @@ def find_bugs_fixed(changes, branch, _lplib=None):
     return bugs
 
 
-def find_extra_authors(changes):
-    """Find additional authors from a changelog entry.
-
-    :return: List of fullnames of additional authors, without e-mail address.
-    """
-    extra_author_re = re.compile(r"\s*\[([^\]]+)]\s*")
-    authors = []
-    for change in changes:
-        # Parse out any extra authors.
-        match = extra_author_re.match(change)
-        if match is not None:
-            new_author = safe_decode(match.group(1).strip())
-            already_included = False
-            for author in authors:
-                if author.startswith(new_author):
-                    already_included = True
-                    break
-            if not already_included:
-                authors.append(new_author)
-    return authors
-
-
-def find_thanks(changes):
-    """Find all people thanked in a changelog entry.
-
-    :param changes: String with the contents of the changelog entry
-    :return: List of people thanked, optionally including email address.
-    """
-    thanks_re = re.compile(
-        r"[tT]hank(?:(?:s)|(?:you))(?:\s*to)?"
-        "((?:\\s+(?:(?:\\w\\.)|(?:\\w+(?:-\\w+)*)))+"
-        "(?:\\s+<[^@>]+@[^@>]+>)?)",
-        re.UNICODE)
-    thanks = []
-    changes_str = safe_decode(" ".join(changes))
-    for match in thanks_re.finditer(changes_str):
-        if thanks is None:
-            thanks = []
-        thanks_str = match.group(1).strip()
-        thanks_str = re.sub(r"\s+", " ", thanks_str)
-        thanks.append(thanks_str)
-    return thanks
-
-
 def get_commit_info_from_changelog(changelog, branch, _lplib=None):
     """Retrieves the messages from the last section of debian/changelog.
 
@@ -525,28 +487,14 @@ def get_commit_info_from_changelog(changelog, branch, _lplib=None):
     if changelog._blocks:
         block = changelog._blocks[0]
         authors = [safe_decode(block.author)]
+        authors += find_extra_authors(block.changes())
         changes = strip_changelog_message(block.changes())
-        authors += find_extra_authors(changes)
-        bugs = find_bugs_fixed(changes, branch, _lplib=_lplib)
-        thanks = find_thanks(changes)
+        bugs = find_bugs_fixed(block.changes(), branch, _lplib=_lplib)
+        thanks = find_thanks(block.changes())
         message = safe_decode("\n".join(changes).replace("\r", ""))
     return (message, authors, thanks, bugs)
 
 
-def find_last_distribution(changelog):
-    """Find the last changelog that was used in a changelog.
-
-    This will skip stanzas with the 'UNRELEASED' distribution.
-
-    :param changelog: Changelog to analyze
-    """
-    for block in changelog._blocks:
-        distribution = block.distributions.split(" ")[0]
-        if distribution != "UNRELEASED":
-            return distribution
-    return None
-
-
 def subprocess_setup():
     # Python installs a SIGPIPE handler by default. This is usually not what
     # non-Python subprocesses expect.
@@ -595,6 +543,11 @@ def debuild_config(tree, subpath):
     return config
 
 
+class UnableToFindPreviousUpload(BzrError):
+
+    _fmt = ("Unable to determine the previous upload for --package-merge.")
+
+
 def find_previous_upload(tree, subpath, merge=False):
     """Given a tree, find the previous upload to the distribution.
 
@@ -614,11 +567,19 @@ def find_previous_upload(tree, subpath, merge=False):
     """
     try:
         cl, top_level = find_changelog(tree, subpath, merge, max_blocks=None)
-    except UnparseableChangelog:
+    except ChangelogParseError:
         raise UnableToFindPreviousUpload()
     return changelog_find_previous_upload(cl)
 
 
+class NoPreviousUpload(BzrError):
+
+    _fmt = ("There was no previous upload to %(distribution)s.")
+
+    def __init__(self, distribution):
+        BzrError.__init__(self, distribution=distribution)
+
+
 def changelog_find_previous_upload(cl):
     """Find the version of the previous upload.
 
@@ -690,6 +651,24 @@ NATIVE_SOURCE_FORMATS = [FORMAT_3_0_NATIVE]
 NORMAL_SOURCE_FORMATS = [FORMAT_3_0_QUILT]
 
 
+class InconsistentSourceFormatError(BzrError):
+
+    _fmt = ("Inconsistency between source format and version: version is "
+            "%(version_bool)snative, format is %(format_bool)snative.")
+
+    def __init__(self, version_native, format_native):
+        if version_native:
+            version_bool = ""
+        else:
+            version_bool = "not "
+        if format_native:
+            format_bool = ""
+        else:
+            format_bool = "not "
+        BzrError.__init__(
+            self, version_bool=version_bool, format_bool=format_bool)
+
+
 def guess_build_type(tree, version, subpath='', contains_upstream_source=True):
     """Guess the build type based on the contents of a tree.
 
